@@ -1,13 +1,13 @@
 package PerlIO::gzip;
 
-use 5.006;
+use 5.007;
 use strict;
 use warnings;
 
 require DynaLoader;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 bootstrap PerlIO::gzip $VERSION;
 
@@ -29,7 +29,10 @@ PerlIO::gzip - Perl extension to provide a PerlIO layer to gzip/gunzip
 =head1 DESCRIPTION
 
 PerlIO::gzip provides a PerlIO layer that manipulates files in the format used
-by the C<gzip> program.  Currently only decompression is implemented.
+by the C<gzip> program.  Currently only decompression is implemented.  If you
+atttempt to open a file for writing (or reading and writing) the open will
+fail. (except in "autopop" mode, where the gzip layer will be automatically
+popped from the file handle instead).
 
 =head1 EXPORT
 
@@ -37,14 +40,14 @@ PerlIO::gzip exports no subroutines or symbols, just a perl layer C<gzip>
 
 =head1 LAYER ARGUMENTS
 
-The C<gzip> layer takes a comma separated list of arguments. 3 exclusive
+The C<gzip> layer takes a comma separated list of arguments. 4 exclusive
 options choose the header checking mode:
 
 =over 4
 
 =item gzip
 
-The default. Expects a standard gzip file header
+The default.  Expects a standard gzip file header.
 
 =item none
 
@@ -55,7 +58,19 @@ stream (eg as would be found inside a C<zip> file)
 
 Potentially dangerous. If the first two bytes match the C<gzip> header
 "\x1f\x8b" then a gzip header is assumed (and checked) else a deflate stream
-is assumed
+is assumed.
+
+=item autopop
+
+Potentially dangerous. If the first two bytes match the C<gzip> header
+"\x1f\x8b" then a gzip header is assumed (and checked) else the layer is
+silently popped.  This results in gzip files being transparently
+decompressed, other files being treated normally.  Of course, this has sides
+effects such as File::Copy becoming gunzip, and File::Compare comparing
+the uncompressed contents of files.
+
+In autopop mode Opening a handle for writing (or reading and writing) will
+cause the gzip layer to automatically be popped.
 
 =back
 
@@ -80,6 +95,8 @@ with the header will cause an error on read.
 If you're not careful you won't spot the errors - like the example above
 you'll think you got end of file.
 
+lazy is ignored if you are in autopop mode.
+
 =back
 
 =head1 AUTHOR
